@@ -71,6 +71,19 @@ def _more_methods_for_backend(tnbackend: Any) -> None:
         e = self.sqrt(e)
         return v @ self.diagflat(e) @ self.adjoint(v)
 
+    def eigvalsh(self: Any, a: Tensor) -> Tensor:
+        """
+        Get the eigenvalues of matrix ``a``.
+
+        :param a: tensor in matrix form
+        :type a: Tensor
+        :return: eigenvalues of ``a``
+        :rtype: Tensor
+        """
+        raise NotImplementedError(
+            "Backend '{}' has not implemented `eigvalsh`.".format(self.name)
+        )
+
     def sin(self: Any, a: Tensor) -> Tensor:
         """
         Return the  elementwise sine of a tensor ``a``.
@@ -1156,11 +1169,9 @@ def _more_methods_for_backend(tnbackend: Any) -> None:
         """
         Compute the Jacobian of ``f`` using the forward mode AD.
 
-        :param self: [description]
-        :type self: Any
-        :param f: [description]
+        :param f: the function whose Jacobian is required
         :type f: Callable[..., Any]
-        :param argnums: [description], defaults to 0
+        :param argnums: the position of the arg as Jacobian input, defaults to 0
         :type argnums: Union[int, Sequence[int]], optional
         :return: outer tuple for input args, inner tuple for outputs
         :rtype: Tensor
@@ -1220,11 +1231,9 @@ def _more_methods_for_backend(tnbackend: Any) -> None:
         """
         Compute the Jacobian of ``f`` using reverse mode AD.
 
-        :param self: [description]
-        :type self: Any
-        :param f: [description]
+        :param f: The function whose Jacobian is required
         :type f: Callable[..., Any]
-        :param argnums: [description], defaults to 0
+        :param argnums: the position of the arg as Jacobian input, defaults to 0
         :type argnums: Union[int, Sequence[int]], optional
         :return: outer tuple for output, inner tuple for input args
         :rtype: Tensor
